@@ -18,17 +18,14 @@
 
 #include "comic.h"
 
-#include <QtCore/QDate>
-#include <QtCore/QFileInfo>
-#include <QtCore/QSettings>
+#include <QDate>
+#include <QFileInfo>
+#include <QSettings>
 #include <QImage>
 #include <QUrl>
 #include <QDebug>
 #include <QStandardPaths>
 
-#include <KServiceTypeTrader>
-#include <KPluginInfo>
-
 #include <Plasma/DataContainer>
 #include <KPackage/PackageLoader>
 
@@ -48,14 +45,13 @@ ComicEngine::~ComicEngine()
 
 void ComicEngine::init()
 {
-    connect(Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
-             this, SLOT(networkStatusChanged(Solid::Networking::Status)));
+    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged,
+            this, &ComicEngine::onOnlineStateChanged);
 }
 
-void ComicEngine::networkStatusChanged(Solid::Networking::Status status)
+void ComicEngine::onOnlineStateChanged(bool isOnline)
 {
-    if ((status == Solid::Networking::Connected || status == Solid::Networking::Unknown) &&
-         !mIdentifierError.isEmpty()) {
+    if (isOnline && !mIdentifierError.isEmpty()) {
         sourceRequestEvent(mIdentifierError);
     }
 }
@@ -64,7 +60,7 @@ void ComicEngine::loadProviders()
 {
     mProviders.clear();
     removeAllData(QLatin1String("providers"));
-    auto comics = KPackage::PackageLoader::self()->listPackages("Plasma/Comic");
+    auto comics = KPackage::PackageLoader::self()->listPackages(QStringLiteral("Plasma/Comic"));
     for (auto comic : comics) {
         mProviders << comic.pluginId();
 
@@ -131,8 +127,7 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
         }
 
         // check if there is a connection
-        Solid::Networking::Status status = Solid::Networking::status();
-        if (status != Solid::Networking::Connected && status != Solid::Networking::Unknown) {
+        if (!m_networkConfigurationManager.isOnline()) {
             mIdentifierError = identifier;
             setData(identifier, QLatin1String("Error"), true);
             setData(identifier, QLatin1String("Error automatically fixable"), true);
@@ -142,15 +137,15 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
             return true;
         }
 
-        KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage("Plasma/Comic", parts[0]);
+        KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("Plasma/Comic"), parts[0]);
 
         bool isCurrentComic = parts[1].isEmpty();
 
         QVariantList args;
-        ComicProvider *provider = 0;
+        ComicProvider *provider = nullptr;
 
         //const QString type = service->property(QLatin1String("X-KDE-PlasmaComicProvider-SuffixType"), QVariant::String).toString();
-        const QString type = pkg.metadata().value("X-KDE-PlasmaComicProvider-SuffixType");
+        const QString type = pkg.metadata().value(QStringLiteral("X-KDE-PlasmaComicProvider-SuffixType"));
         if (type == QLatin1String("Date")) {
             QDate date = QDate::fromString(parts[1], Qt::ISODate);
             if (!date.isValid())
@@ -321,7 +316,7 @@ QString ComicEngine::lastCachedIdentifier(const QString &identifier) const
 {
         const QString id = identifier.left(identifier.indexOf(QLatin1Char(':')));
         QString data = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/plasma_engine_comic/");
-        data += QString::fromAscii(QUrl::toPercentEncoding(id));
+        data += QString::fromLatin1(QUrl::toPercentEncoding(id));
         QSettings settings(data + QLatin1String(".conf"), QSettings::IniFormat);
         QString previousIdentifier = settings.value(QLatin1String("lastCachedStripIdentifier"), QString()).toString();
 
