@@ -23,6 +23,10 @@
 #define NOAAPROVIDER_H
 
 #include "potdprovider.h"
+// Qt
+#include <QImage>
+
+class KJob;
 
 /**
  * This class provides the image for NOAA Environmental Visualization Laboratory
@@ -45,7 +49,7 @@ class NOAAProvider : public PotdProvider
         /**
          * Destroys the NOAA provider.
          */
-        ~NOAAProvider();
+        ~NOAAProvider() override;
 
         /**
          * Returns the requested image.
@@ -53,11 +57,14 @@ class NOAAProvider : public PotdProvider
          * Note: This method returns only a valid image after the
          *       finished() signal has been emitted.
          */
-        QImage image() const Q_DECL_OVERRIDE;
+        QImage image() const override;
 
     private:
-      class Private;
-      Private* const d;
+        void pageRequestFinished(KJob *job);
+        void imageRequestFinished(KJob *job);
+
+   private:
+        QImage mImage;
 };
 
 #endif
